@@ -1,13 +1,18 @@
-if __name__ == "__main__":
-    import typer
+def main():
     import sys
+
+    import typer
     from wasabi import msg
+
     from . import cli
 
     commands = {
         "create-wikigraph": cli.create_wikigraph,
+        "download-wikigraph": cli.download_wikigraph,
         "package-wikigraph": cli.package_wikigraph,
-        "profile": cli.profile,
+        "profile-matcher": cli.profile_matcher,
+        "profile-wikigraph-load": cli.profile_wikigraph_load,
+        "profile-wikigraph-exec": cli.profile_wikigraph_exec,
     }
 
     if len(sys.argv) == 1:
@@ -19,3 +24,7 @@ if __name__ == "__main__":
     else:
         available = "Available: {}".format(", ".join(commands))
         msg.fail("Unknown command: {}".format(command), available, exits=1)
+
+
+if __name__ == "__main__":
+    main()
